Installation is as simple as:

=== "pip"

    ```bash
    pip install pyrmute
    ```

=== "uv"

    ```bash
    uv add pyrmute
    ```

pyrmute only has one dependency: [`pydantic`](https://pypi.org/project/pydantic/)

If you've got Python 3.11+ and `pip` installed, you're good to go.

## Install from repository

And if you prefer to install pyrmute directly from the repository:

=== "pip"

    ```bash
    pip install 'git+https://github.com/mferrera/pyrmute@main'
    ```

=== "uv"

    ```bash
    uv add 'git+https://github.com/mferrera/pyrmute@main'
    ```
